@@ -1,9 +1,9 @@
 package Egg::Helper::Project::BlankPage;
 #
 # Copyright 2007 Bee Flag, Corp. All Rights Reserved.
-# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: BlankPage.pm 204 2007-02-19 17:50:52Z lushe $
+# $Id: BlankPage.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 
@@ -156,7 +156,7 @@ L<Egg::Release>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>
+Masatoshi Mizuno, E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
